"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefineGroup = exports.META_GROUPNAME = void 0;
const common_1 = require("@nestjs/common");
exports.META_GROUPNAME = 'keycloak-groupname';
/**
 * Decorator that assigns Metadata to be used by a GroupGuard.
 *
 * For example: \
 * `@DefineGroup('read', 'project', 'unlimited', 'projectId')` \
 * `@UseGuards(GroupGuard)`
 *
 * @param scopeType CRUD operation.
 * @param groupName Prefix that is used by all Keycloak groups.
 * @param unlimitedSuffix Optional parameter, that defines a scope, that can bypass the GroupGuard.
 * @param paramName Optional suffix that defines to which URL parameter the group is referred to.
 * Defaults to groupName + "Id"
 *
 * @fritzforsit
 */
const DefineGroup = (scopeType, groupName, unlimitedSuffix, paramName) => (0, common_1.SetMetadata)(exports.META_GROUPNAME, {
    scopeType: scopeType,
    groupName: groupName,
    unlimitedSuffix: unlimitedSuffix,
    paramName: paramName ? paramName : groupName + 'Id',
});
exports.DefineGroup = DefineGroup;
//# sourceMappingURL=group.decorator.js.map