"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefineScope = exports.META_SCOPE = void 0;
const common_1 = require("@nestjs/common");
exports.META_SCOPE = 'keycloak-scope';
/**
 * Decorator that assigns Metadata to be used by a ResourceGuard.
 * Must used in combination with the @DefineResource decorator.
 * Limits access to Users who own the supplied scope.
 *
 * For example: \
 * `@DefineResource('administration')` \
 * `@DefineScope(CRUD.read)`
 *
 * @param scopeType CRUD type of the Keycloak resource scope.
 * @param scopeName Optional argument for checking supplied ownership of a specific scope.
 *
 * @fritzforsit
 */
const DefineScope = (scopeType, scopeName) => (0, common_1.SetMetadata)(exports.META_SCOPE, {
    scopeType: scopeType,
    scopeName: scopeName,
});
exports.DefineScope = DefineScope;
//# sourceMappingURL=scope.decorator.js.map