import { CanActivate, ExecutionContext, Logger } from '@nestjs/common';
import { Reflector } from '@nestjs/core';
/**
 * Guard that is used to restrict access within a UMA resource by Keycloak
 * group membership. Must be run after a ResourceGuard.
 * Use the @DefineGroup decorator to define the group prefix.
 * If the @DefineGroup decorator is given an unlimitedScopeSuffix, access to this scope
 * bypasses the GroupGuard.
 * The Guards expects a url param paramName. This defaults to groupName + "Id", for example,
 * if groupName is project, the default value for paramName is projectId.
 * The Guard grants access, if the user is a member of the Keycloak group.
 *
 * For example: \
 * `@Get()` \
 * `@DefineGroup('project','create','unlimited')` \
 * `@UseGuards(GroupGuard)` \
 * `function(@Param param: any) {}`
 *
 * @fritzforsit
 */
export declare class GroupGuard implements CanActivate {
    private readonly reflector;
    logger: Logger;
    constructor(reflector: Reflector);
    getRequest(context: ExecutionContext): any;
    canActivate(context: ExecutionContext): boolean | Promise<boolean>;
}
//# sourceMappingURL=group.guard.d.ts.map