"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var GroupGuard_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupGuard = void 0;
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const scope_1 = require("../@types/scope");
const group_decorator_1 = require("../decorators/group.decorator");
/**
 * Guard that is used to restrict access within a UMA resource by Keycloak
 * group membership. Must be run after a ResourceGuard.
 * Use the @DefineGroup decorator to define the group prefix.
 * If the @DefineGroup decorator is given an unlimitedScopeSuffix, access to this scope
 * bypasses the GroupGuard.
 * The Guards expects a url param paramName. This defaults to groupName + "Id", for example,
 * if groupName is project, the default value for paramName is projectId.
 * The Guard grants access, if the user is a member of the Keycloak group.
 *
 * For example: \
 * `@Get()` \
 * `@DefineGroup('project','create','unlimited')` \
 * `@UseGuards(GroupGuard)` \
 * `function(@Param param: any) {}`
 *
 * @fritzforsit
 */
let GroupGuard = GroupGuard_1 = class GroupGuard {
    constructor(reflector) {
        this.reflector = reflector;
        this.logger = new common_1.Logger(GroupGuard_1.name);
    }
    getRequest(context) {
        return context.switchToHttp().getRequest();
    }
    canActivate(context) {
        const meta = this.reflector.get(group_decorator_1.META_GROUPNAME, context.getHandler());
        try {
            const request = this.getRequest(context);
            if (meta.unlimitedSuffix) {
                let unlimitedScopeName = `${scope_1.CRUD[meta.scopeType]}-${meta.unlimitedSuffix}`;
                if (request.scopes.includes(unlimitedScopeName)) {
                    return true;
                }
            }
            let limitedScopeName = `${meta.scopeType}-${meta.groupName}-limited`;
            if (request.scopes.includes(limitedScopeName)) {
                const allGroups = request.user.groups;
                if (!allGroups) {
                    return false;
                }
                const groups = request.user.groups.filter((group) => {
                    return group.startsWith(meta.groupName);
                });
                if (!groups) {
                    return false;
                }
                const groupIds = groups.map((group) => {
                    return group.replace(meta.groupName, '');
                });
                if (groupIds.includes(request.param[meta.paramName])) {
                    return true;
                }
            }
            return false;
        }
        catch (error) {
            this.logger.error(`Uncaught exception handling user info`, error);
            throw new common_1.UnauthorizedException();
        }
    }
};
GroupGuard = GroupGuard_1 = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [core_1.Reflector])
], GroupGuard);
exports.GroupGuard = GroupGuard;
//# sourceMappingURL=group.guard.js.map