"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var ResourceGuard_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceGuard = void 0;
const common_1 = require("@nestjs/common");
const service_1 = require("../service");
const core_1 = require("@nestjs/core");
const scope_decorator_1 = require("../decorators/scope.decorator");
const uma_ticket_1 = require("../@types/uma.ticket");
const resource_decorator_1 = require("../decorators/resource.decorator");
const public_decorator_1 = require("../decorators/public.decorator");
const scope_1 = require("../@types/scope");
/**
 * Guard that is used to protect a UMA resource. If a resource is defined
 * with the @DefineResource decorator, the guard checks the users access to
 * any scopes of that resource on Keycloak.
 * Resource name and all authorised scopes are stored in the request.
 *
 * If used with a @DefineScope decorator, the guard checks access for the
 * given scope and does not append to the request.
 *
 * For example: \
 * `@DefineResource('administration')` \
 * `@UseGuards(ResourceGuard)`

 * @fritzforsit
 */
let ResourceGuard = ResourceGuard_1 = class ResourceGuard {
    constructor(keycloak, reflector) {
        this.keycloak = keycloak;
        this.reflector = reflector;
        this.logger = new common_1.Logger(ResourceGuard_1.name);
    }
    getRequest(context) {
        return context.switchToHttp().getRequest();
    }
    async canActivate(context) {
        const isPublic = this.reflector.get(public_decorator_1.META_PUBLIC, context.getHandler());
        // Emit process, if endpoint is public.
        if (isPublic) {
            return true;
        }
        const request = this.getRequest(context);
        const resource = this.reflector.get(resource_decorator_1.META_RESOURCE, context.getClass());
        // If no @DefineScope() decorator is used in handler, it's generated from http method.
        const scopeData = this.reflector.get(scope_decorator_1.META_SCOPE, context.getHandler());
        let scope = undefined;
        if (scopeData) {
            if (scopeData.scopeType && scopeData.scopeName) {
                scope = `${scope_1.CRUD[scopeData.scopeType]}-${scopeData.scopeName}`;
            }
        }
        // If no resource type is defined as class decorator, emit.
        if (!resource) {
            return true;
        }
        // If no access token is defined, probably auth guard failed to load.
        if (!request.accessToken) {
            throw new common_1.UnauthorizedException();
        }
        try {
            const response = await this.keycloak.permissionManager.requestTicket({
                token: request.accessToken,
                audience: this.keycloak.options.clientId,
                resourceId: resource,
                scope: scope ? `${scope}` : undefined,
                response_mode: scope ? uma_ticket_1.TicketResponseMode.decision : uma_ticket_1.TicketResponseMode.permissions,
            });
            if (response.error) {
                switch (response.error) {
                    case 'access_denied':
                        return false;
                    default:
                        this.logger.error('Exception from UMA server', response);
                        return false;
                }
            }
            if (!!scope) {
                if (response.result)
                    return true;
                return false;
            }
            const [{ scopes, rsid }] = response;
            request.scopes = scopes;
            request.resource = await this.keycloak.resourceManager.findById(rsid);
            // check for ownership of any scopes with specific CRUD type
            if (!scopeData) {
                return true;
            }
            if (scopes.find((scopeName) => {
                return scopeName.startsWith(scope_1.CRUD[scopeData.scopeType]);
            })) {
                return true;
            }
        }
        catch (error) {
            this.logger.error(`Uncaught exception from UMA server`, error);
        }
        throw new common_1.UnauthorizedException();
    }
};
ResourceGuard = ResourceGuard_1 = __decorate([
    (0, common_1.Injectable)(),
    __param(0, (0, common_1.Inject)(service_1.KeycloakService)),
    __metadata("design:paramtypes", [service_1.KeycloakService,
        core_1.Reflector])
], ResourceGuard);
exports.ResourceGuard = ResourceGuard;
//# sourceMappingURL=resource.guard.js.map