export declare const User: (...dataOrPipes: unknown[]) => ParameterDecorator;
/**
 * Parameter Decorator that is used to retrieve the ids of all
 * Keycloak groups with the given prefix the User is a member of.
 *
 * For example:
 * `function(@UserGroups('project') groups: number[])`
 *
 * @param groupName prefix for the Keycloak groups.
 *
 * @returns number[]: a list of the groups ids.
 *
 * @fritzforsit
 */
export declare const UserGroups: (...dataOrPipes: (string | import("@nestjs/common").PipeTransform<any, any> | import("@nestjs/common").Type<import("@nestjs/common").PipeTransform<any, any>>)[]) => ParameterDecorator;
/**
 * Parameter Decorator that is used to retrieve all user resource scopes.
 * Must be run after a RessourceGuard is used without the @DefineScope decorator
 *
 * For example:
 * `function(@UserGScopes() scopes: string[])`
 *
 * @returns string[]: a list of all resource scopes the user has access to on the
 * current resource.
 *
 * @fritzforsit
 */
export declare const UserScopes: (...dataOrPipes: any[]) => ParameterDecorator;
/**
 * Parameter Decorator that is used retrieve the current users Keycloak Roles.
 *
 * For example:
 * `function(@UserRoles() userRoles: string[])`
 *
 * @returns string[]: the users Keycloak roles
 *
 * @fritzforsit
 */
export declare const UserRoles: (...dataOrPipes: any[]) => ParameterDecorator;
/**
 * Parameter Decorator that is used retrieve the current users Keycloak id.
 *
 * For example:
 * `function(@UserId() userId: string)`
 *
 * @returns string: the Keycloak Id
 *
 * @fritzforsit
 */
export declare const UserId: (...dataOrPipes: any[]) => ParameterDecorator;
//# sourceMappingURL=user.decorator.d.ts.map