var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var ResourceGuard_1;
import { Injectable, UnauthorizedException, Logger, Inject, } from '@nestjs/common';
import { KeycloakService } from '../service';
import { Reflector } from '@nestjs/core';
import { META_SCOPE } from '../decorators/scope.decorator';
import { TicketResponseMode, } from '../@types/uma.ticket';
import { META_RESOURCE } from '../decorators/resource.decorator';
import { META_PUBLIC } from '../decorators/public.decorator';
import { CRUD } from '../@types/scope';
/**
 * Guard that is used to protect a UMA resource. If a resource is defined
 * with the @DefineResource decorator, the guard checks the users access to
 * any scopes of that resource on Keycloak.
 * Resource name and all authorised scopes are stored in the request.
 *
 * If used with a @DefineScope decorator, the guard checks access for the
 * given scope and does not append to the request.
 *
 * For example: \
 * `@DefineResource('administration')` \
 * `@UseGuards(ResourceGuard)`

 * @fritzforsit
 */
let ResourceGuard = ResourceGuard_1 = class ResourceGuard {
    keycloak;
    reflector;
    logger = new Logger(ResourceGuard_1.name);
    constructor(keycloak, reflector) {
        this.keycloak = keycloak;
        this.reflector = reflector;
    }
    getRequest(context) {
        return context.switchToHttp().getRequest();
    }
    async canActivate(context) {
        const isPublic = this.reflector.get(META_PUBLIC, context.getHandler());
        // Emit process, if endpoint is public.
        if (isPublic) {
            return true;
        }
        const request = this.getRequest(context);
        const resource = this.reflector.get(META_RESOURCE, context.getClass());
        // If no @DefineScope() decorator is used in handler, it's generated from http method.
        const scopeData = this.reflector.get(META_SCOPE, context.getHandler());
        let scope = undefined;
        if (scopeData) {
            if (scopeData.scopeType && scopeData.scopeName) {
                scope = `${CRUD[scopeData.scopeType]}-${scopeData.scopeName}`;
            }
        }
        // If no resource type is defined as class decorator, emit.
        if (!resource) {
            return true;
        }
        // If no access token is defined, probably auth guard failed to load.
        if (!request.accessToken) {
            throw new UnauthorizedException();
        }
        try {
            const response = await this.keycloak.permissionManager.requestTicket({
                token: request.accessToken,
                audience: this.keycloak.options.clientId,
                resourceId: resource,
                scope: scope ? `${scope}` : undefined,
                response_mode: scope ? TicketResponseMode.decision : TicketResponseMode.permissions,
            });
            if (response.error) {
                switch (response.error) {
                    case 'access_denied':
                        return false;
                    default:
                        this.logger.error('Exception from UMA server', response);
                        return false;
                }
            }
            if (!!scope) {
                if (response.result)
                    return true;
                return false;
            }
            const [{ scopes, rsid }] = response;
            request.scopes = scopes;
            request.resource = await this.keycloak.resourceManager.findById(rsid);
            // check for ownership of any scopes with specific CRUD type
            if (!scopeData) {
                return true;
            }
            if (scopes.find((scopeName) => {
                return scopeName.startsWith(CRUD[scopeData.scopeType]);
            })) {
                return true;
            }
        }
        catch (error) {
            this.logger.error(`Uncaught exception from UMA server`, error);
        }
        throw new UnauthorizedException();
    }
};
ResourceGuard = ResourceGuard_1 = __decorate([
    Injectable(),
    __param(0, Inject(KeycloakService)),
    __metadata("design:paramtypes", [KeycloakService,
        Reflector])
], ResourceGuard);
export { ResourceGuard };
//# sourceMappingURL=resource.guard.js.map